#!/bin/sh

build_module () {
	echo =====================================
	echo build module $1 \($2\)
	echo =====================================
	echo ------------
	echo build source
        echo ------------
	cd src/modules
	if [ "$2" = "ocspd" ] ; then
		module_version=`cat openca-${2}/VERSION`
	elif [ "$2" = "sv" ] ; then
		module_version=`cat openca-${2}/VERSION`
	else
		module_version=`perl -MExtUtils::MakeMaker -le "print MM->parse_version(shift)" "openca-${2}/${1}.pm"`
	fi
	cp -r openca-${2} OpenCA-${1}-${module_version}
	tar cpf OpenCA-${1}-${module_version}.tar --exclude "CVS" OpenCA-${1}-${module_version}
	gzip OpenCA-${1}-${module_version}.tar
	mv OpenCA-${1}-${module_version}.tar.gz ${SOURCES}
	rm -rf OpenCA-${1}-${module_version}
	echo ---------
	echo build RPM
        echo ---------
	rpm --clean -ba openca-${2}/specs/${DISTRIBUTION}.spec
	echo -------
	echo cleanup
	echo -------
	rm -f ${SOURCES}/OpenCA-${1}-${module_version}.tar.gz
	cd ../..
	## all RPMs are placed in the root of the source
	## some distributions like SuSE use perl-Module-Name
	mv ${RPMS}/*/*OpenCA-${1}-*.rpm .
	mv ${SRPMS}/*OpenCA-${1}-*.rpm .
}

echo ==========================
echo starting to create the RPM
echo ==========================

pkg=OpenCA
pkg_ca=${pkg}-CA
pkg_ext=${pkg}-RAServer
pkg_common=${pkg}-common

spec_ca=openca-ca
spec_ext=openca-raserver
spec_common=openca-common

ver=0.9.0
export ver
echo ==============
echo Version: $ver
echo ==============

arc="${ver}.tar.gz"
arc_ca="${pkg_ca}-${arc}"
spec_ca="contrib/rpm/${spec_ca}.spec"

arc_ext="${pkg_ext}-${arc}"
spec_ext="contrib/rpm/${spec_ext}.spec"

arc_common="${pkg_common}-${arc}"
spec_common="contrib/rpm/${spec_common}.spec"

# default is redhat
DISTRIBUTION=redhat
RPM_BASE=/usr/src/redhat
SOURCES=${RPM_BASE}/SOURCES
SRPMS=${RPM_BASE}/SRPMS
RPMS=${RPM_BASE}/RPMS

if [ "$2" = "suse" ] ; then
	DISTRIBUTION=suse
	RPM_BASE=/usr/src/packages
	SOURCES=${RPM_BASE}/SOURCES
	SRPMS=${RPM_BASE}/SRPMS
	RPMS=${RPM_BASE}/RPMS
fi

export DISTRIBUTION
echo ===========================
echo build all for $DISTRIBUTION
echo ===========================


if [ "$1" = "ca" ] ; then
	echo ================
	echo build all for CA
	echo ================
	make ca-src
	cp "${arc_ca}" "${SOURCES}"
	rpm -ba ${spec_ca}
	mv ${RPMS}/*/${pkg_ca}*.rpm .
	mv ${SRPMS}/${pkg_ca}*.rpm .
	rm -f ${SOURCES}/${arc_ca}
fi

if [ "$1" = "ra" ] ; then
	echo ======================
	echo build all for RAServer
	echo ======================
	make ra-src
	cp "${arc_ext}" "${SOURCES}"
	rpm -ba ${spec_ext}
	mv ${RPMS}/*/${pkg_ext}*.rpm .
	mv ${SRPMS}/${pkg_ext}*.rpm .
	rm -f ${SOURCES}/${arc_ext}
fi

if [ "$1" = "common" ] ; then
	echo ======================
	echo build all common parts
	echo ======================
	make common-src
	cp "${arc_common}" "${SOURCES}"
	rpm -ba ${spec_common}
	mv ${RPMS}/*/${pkg_common}*.rpm .
	mv ${SRPMS}/${pkg_common}*.rpm .
	rm -f ${SOURCES}/${arc_common}
fi

if [ "$1" = "modules" ] ; then
	build_module "Configuration" "configuration"
	build_module "CRL" "crl"
	build_module "DB" "db"
	build_module "DBI" "dbi"
	build_module "OCSPD" "ocspd"
	build_module "OpenSSL" "openssl"
	build_module "PKCS7" "pkcs7"
	build_module "REQ" "req"
	build_module "SV" "sv"
	build_module "Tools" "tools"
	build_module "TRIStateCGI" "tristatecgi"
	build_module "X509" "x509"
fi

exit 0;
