/* OpenCA OCSP daemon - (c) 2000 by Massimiliano Pala and OpenCA Group */
#include "config.h"

/* External Variables */
#if STDC_HEADERS
# include <string.h>
# include <stdio.h>
# include <stdlib.h>
#else
# ifndef HAVE_STRCHR
#  define strchr index
#  define strrchr rindex
# endif
char *strchr (), *strrchr ();
# ifndef HAVE_MEMCPY
#  define memcpy(d, s, n) bcopy ((s), (d), (n))
#  define memmove(d, s, n) bcopy ((s), (d), (n))
# endif
#endif

#include <syslog.h>
#include <ctype.h>
#include <sys/types.h>
#include <signal.h>
#include <sys/types.h>
#include <sys/stat.h>

#include <openssl/conf.h>
#include <openssl/bio.h>
#include <openssl/err.h>
#include <openssl/bn.h>
#include <openssl/txt_db.h>
#include <openssl/evp.h>
#include <openssl/x509.h>
#include <openssl/x509v3.h>
#include <openssl/objects.h>
#include <openssl/ocsp.h> 
#include <openssl/pem.h>


#include <openssl/ocsp.h>

#define HTTP_POST		0
#define HTTP_GET		1
#define HTTP_POST_METHOD	"POST"
#define HTTP_GET_METHOD		"GET"

#define OCSP_REQ_TYPE		"application/ocsp-request"
#define OCSP_RESP_TYPE		"application/ocsp-response"

#define BASE_SECTION    	"ocspd"
#define CONFIG_FILE 		"ocspd.conf"
#define ENV_SECTION 		"conf_section"

#define ENV_DEFAULT_OCSPD	"default_ocspd"
#define ENV_DATABASE            "db"
#define ENV_PRIVATE_KEY		"ocspd_key"
#define ENV_CERTIFICATE		"ocspd_certificate"
#define ENV_CA_CERTIFICATE	"ca_certificate"
#define ENV_OCSPD_PORT		"port"
#define ENV_OCSPD_BIND		"bind"
#define ENV_OCSPD_CHILD		"servers"
#define ENV_OCSPD_QUEUE		"clients_per_server"
#define ENV_OCSPD_MAXRS		"max_req_size"
#define ENV_OCSPD_MD		"md"
#define ENV_OCSPD_PIDFILE	"pidfile"
#define ENV_OCSPD_RESPONSE	"response"
#define ENV_OCSPD_RESPONSE_KEYID "ocsp_add_response_keyid"
#define ENV_OCSPD_RESPONSE_OTHER_CERTS "ocsp_add_response_certs"
#define ENV_OCSPD_RESPONSE_DAYS	"next_update_days"
#define ENV_OCSPD_RESPONSE_MINS	"next_update_mins"

#define ENV_OCSPD_USER		"user"
#define ENV_OCSPD_GROUP		"group"

#define OCSP_REQ_CONTENT_TYPE	"application/ocsp-request"
#define OCSP_RESP_CONTENT_TYPE	"application/ocsp-response"

#define DB_type         0
#define DB_exp_date     1
#define DB_rev_date     2
#define DB_serial       3       /* index - unique */
#define DB_file         4       
#define DB_name         5       /* index - unique for active */
#define DB_NUMBER       6

#define DB_TYPE_REV     'R'
#define DB_TYPE_EXP     'E'
#define DB_TYPE_VAL     'V'
#define DB_TYPE_SUS     'S'
#define DB_TYPE_UNK     'U'

#define FORMAT_UNDEF    0
#define FORMAT_ASN1     1
#define FORMAT_TEXT     2
#define FORMAT_PEM      3
#define FORMAT_NETSCAPE 4
#define FORMAT_PKCS12   5
#define FORMAT_SMIME    6
#define FORMAT_ENGINE   7

#define APP_PASS_LEN    1024

typedef struct pw_cb_data
	{
	const void *password;
	const char *prompt_info;
	} PW_CB_DATA;

typedef struct ocspd_config {
	CONF * conf;
	TXT_DB *db;
	EVP_MD *digest;
	int nmin;
	int ndays;
	int flags;
	EVP_PKEY *ocspd_pkey;
	X509 *ocspd_cert;
	X509 *cacert;
	STACK_OF(X509) *other_certs;

} OCSPD_CONFIG;

