/*
 * scepxid.c -- compute the transaction id belonging to some RSA private
 *              key
 *
 * (c) 2001 Dr. Andreas Mueller, Beratung und Entwicklung
 *
 * $Id: scepxid.c,v 1.2 2001/03/25 16:49:47 afm Exp $
 */
#include <config.h>
#include <init.h>
#include <scep.h>
#include <stdlib.h>
#include <stdio.h>
#include <openssl/bio.h>
#include <openssl/evp.h>
#include <openssl/rsa.h>
#include <openssl/err.h>
#include <openssl/pem.h>
#include <fingerprint.h>

extern int	optind;
extern char	*optarg;

int	main(int argc, char *argv[]) {
	int		c;
	char		*keyfile = NULL, *fp;
	BIO		*bio;
	EVP_PKEY	*pkey;

	/* parse command line						*/
	while (EOF != (c = getopt(argc, argv, "d"))) 
		switch (c) {
		case 'd':
			debug++;
			break;
		}

	/* remaining argument must be the name of the rsa key file	*/
	if ((argc - optind) != 1) {
		fprintf(stderr, "%s:%d: exactly one argument expected: "
			"keyfile\n", __FILE__, __LINE__);
		exit(EXIT_FAILURE);
	}
	keyfile = argv[optind];
	if (debug)
		BIO_printf(bio_err, "%s:%d: key file is %s\n", __FILE__,
			__LINE__, keyfile);

	/* initialize everything you can				*/
	scepinit();

	/* open the key file						*/
	bio = BIO_new(BIO_s_file());
	BIO_read_filename(bio, keyfile);
	if ((pkey = PEM_read_bio_PrivateKey(bio, NULL, NULL, NULL)) == NULL) {
		BIO_printf(bio_err, "%s:%d: cannot read private key\n",
			__FILE__, __LINE__);
		goto err;
	}

	/* compute the fingerprint for this key				*/
	fp = key_fingerprint(pkey);
	if (fp == NULL) {
		BIO_printf(bio_err, "%s:%s: no key fingerprint obtained\n",
			__FILE__, __LINE__);
		goto err;
	}

	/* display the fingerprint					*/
	printf("public key fingerprint: %s\n", fp);

	/* return success						*/
	exit(EXIT_SUCCESS);

	/* error return							*/
err:
	ERR_print_errors(bio_err);
	exit(EXIT_FAILURE);
}
